==> knative-model-5.0.2-sources.jar: annotations/io/fabric8/knative/serving/v1/ContainerStatusesFluentImpl.java <==
package io.fabric8.knative.serving.v1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class ContainerStatusesFluentImpl<A extends ContainerStatusesFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ContainerStatusesFluent<A> {

    private String imageDigest;
    private String name;

    public ContainerStatusesFluentImpl() {
    }

    public ContainerStatusesFluentImpl(ContainerStatuses instance) {
        this.withImageDigest(instance.getImageDigest()); 
        this.withName(instance.getName()); 
    }

    public String getImageDigest() {
        return this.imageDigest;
    }

    public A withImageDigest(String imageDigest) {
        this.imageDigest=imageDigest; return (A) this;
    }

    public Boolean hasImageDigest() {
        return this.imageDigest != null;
    }

    public A withNewImageDigest(String arg1) {
        return (A)withImageDigest(new String(arg1));
    }

    public A withNewImageDigest(StringBuilder arg1) {
        return (A)withImageDigest(new String(arg1));
    }

    public A withNewImageDigest(StringBuffer arg1) {
        return (A)withImageDigest(new String(arg1));
    }

    public String getName() {
        return this.name;
    }

    public A withName(String name) {
        this.name=name; return (A) this;
    }

    public Boolean hasName() {
        return this.name != null;
    }

    public A withNewName(String arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuilder arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1) {
        return (A)withName(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ContainerStatusesFluentImpl that = (ContainerStatusesFluentImpl) o;
        if (imageDigest != null ? !imageDigest.equals(that.imageDigest) :that.imageDigest != null) return false;
        if (name != null ? !name.equals(that.name) :that.name != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(imageDigest,  name,  super.hashCode());
    }

}

==> knative-model-5.3.1-sources.jar: annotations/io/fabric8/knative/serving/v1/ContainerStatusesFluentImpl.java <==
package io.fabric8.knative.serving.v1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class ContainerStatusesFluentImpl<A extends ContainerStatusesFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ContainerStatusesFluent<A> {

    private String imageDigest;
    private String name;

    public ContainerStatusesFluentImpl() {
    }

    public ContainerStatusesFluentImpl(ContainerStatuses instance) {
        this.withImageDigest(instance.getImageDigest()); 
        this.withName(instance.getName()); 
    }

    public String getImageDigest() {
        return this.imageDigest;
    }

    public A withImageDigest(String imageDigest) {
        this.imageDigest=imageDigest; return (A) this;
    }

    public Boolean hasImageDigest() {
        return this.imageDigest != null;
    }

    public A withNewImageDigest(StringBuilder arg1) {
        return (A)withImageDigest(new String(arg1));
    }

    public A withNewImageDigest(int[] arg1,int arg2,int arg3) {
        return (A)withImageDigest(new String(arg1, arg2, arg3));
    }

    public A withNewImageDigest(char[] arg1) {
        return (A)withImageDigest(new String(arg1));
    }

    public A withNewImageDigest(StringBuffer arg1) {
        return (A)withImageDigest(new String(arg1));
    }

    public A withNewImageDigest(byte[] arg1,int arg2) {
        return (A)withImageDigest(new String(arg1, arg2));
    }

    public A withNewImageDigest(byte[] arg1) {
        return (A)withImageDigest(new String(arg1));
    }

    public A withNewImageDigest(char[] arg1,int arg2,int arg3) {
        return (A)withImageDigest(new String(arg1, arg2, arg3));
    }

    public A withNewImageDigest(byte[] arg1,int arg2,int arg3) {
        return (A)withImageDigest(new String(arg1, arg2, arg3));
    }

    public A withNewImageDigest(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withImageDigest(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewImageDigest(String arg1) {
        return (A)withImageDigest(new String(arg1));
    }

    public String getName() {
        return this.name;
    }

    public A withName(String name) {
        this.name=name; return (A) this;
    }

    public Boolean hasName() {
        return this.name != null;
    }

    public A withNewName(StringBuilder arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(int[] arg1,int arg2,int arg3) {
        return (A)withName(new String(arg1, arg2, arg3));
    }

    public A withNewName(char[] arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(byte[] arg1,int arg2) {
        return (A)withName(new String(arg1, arg2));
    }

    public A withNewName(byte[] arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(char[] arg1,int arg2,int arg3) {
        return (A)withName(new String(arg1, arg2, arg3));
    }

    public A withNewName(byte[] arg1,int arg2,int arg3) {
        return (A)withName(new String(arg1, arg2, arg3));
    }

    public A withNewName(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withName(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewName(String arg1) {
        return (A)withName(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ContainerStatusesFluentImpl that = (ContainerStatusesFluentImpl) o;
        if (imageDigest != null ? !imageDigest.equals(that.imageDigest) :that.imageDigest != null) return false;
        if (name != null ? !name.equals(that.name) :that.name != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(imageDigest,  name,  super.hashCode());
    }

}
